nav .navbar-right a.dropdown-toggle {
    padding: 2px 6px 2px 4px;
}

#list {
    border: none;
}

#list .display-control{
    margin-bottom: 15px;
}

.popup-images {
    position: absolute;
    right: 15px;
    top: 5px;
}

.popup-images > img {
    width: 20px;
    height: 20px;
}

.popup-images > img:hover {
    width: 45px;
    height: 45px;
}

#list img.media-object{
    width: 62px;
    height: 62px;
}

#list .profile-entry {
    margin: 0;
    border-bottom: 1px solid #eee;
    padding: 10px 0 10px 10px;
}

#list .profile-entry:first-child {
    border-top: 1px solid #eee;
}

.list-title a {
    font-size: 1.2em;
    color: #05486f;
}

.list-title {
    position: relative;
    margin-bottom: 10px;
}

.list-profile-link {
    font-size: 1.1em;
    margin-left: 15px;
}

dl.list-properties dd {
    display: inline-block;
}
dl.list-properties dt {
    display: inline-block;
    text-transform: uppercase;
    font-weight: normal;
    min-width: 50px;
    font: "monospace";
}

#list .times {
    display: inline-block;
    float: right;
}

.vm-name {
}

.profile-entry:hover {
    cursor: pointer;
    background: #eee;
}

#list .profile-entry .times:hover {
    cursor: pointer;
}

#list .profile-entry .media-body {
    padding-left: 2px;
}


#register {
    padding: 40px;
    max-width: 800px;
}

#register {
    padding: 40px;
    max-width: 900px;
}

#register h1 {
    text-align: center;
    margin-bottom: 20px;
}

#register .control-label {
    padding-right: 10px;
}

#register .help-block {
    padding-left: 10px;
    font-size: 13px;
}

#login {
    padding: 40px;
    max-width: 500px;
}

#login .logo, #register .logo {
    width: 300px
}

#login h1 {
    text-align: center;
    margin-bottom: 20px;
}

#login input {
    margin-bottom: 10px;
}

#login button {
    margin-top: 20px;
}

img.loading {
    position: fixed;
    width: 60px;
    top: 40%;
    left: 50%;
    transform: translate(-50%, -50%);
}

#item header {
    padding-left: 15px;
    margin-bottom: 30px;
}

#item header .times {
    font-size: 30px;
    margin-bottom: 10px;
}

#item header .metadata {
    font-size: 16px;
    display: block;
}

#item header .metadata .label {
    margin-right: 5px;
}

.paths {
    margin-left: 10px;
}

.table {
    margin-bottom: 0;
}

svg rect, svg text {
    cursor: pointer;
    cursor: hand;
}

.footer {
    padding: 20px;
}

#visualization {
    margin-top: 5px;
}

#wide-popovers .popover {
    max-width: none;
}

.trace {
    font: Courier, monospace;
    background: #f8f8f8;
    padding: 15px;
    border: 1px solid #e8e8e8;
}

.trace-type-ctrl {
    padding: 5px;
}

.trace-nav-up {
    color: black;
}

.svg-arrow {
    fill: white;
    stroke: white;
    stroke-width: 1px;
}

span.resop-name {
    color: #a71d5d;
    font-weight: italic;
}

span.resop-descr {
    font-size: 0.7em;
    color: gray;
}

a.resop-descr {
    font-size: 0.7em;
    cursor: pointer;
}

span.resop-run-count {
    font-size: 0.7em;
    color: skyblue;
}

.trace-asm {
    margin-left: 31px;
    color: #969896;
    font-size: 14px;
}

.trace-bg-active {
    fill: #a8a8a8;
}

.trace-jd-name {
    position: absolute;
    right: 0;
    color: #50cB81;
}

.trace-entry > div {
    position: relative;
}

.instr {
    height: 20px;
    font-size: 15px;
    vertical-align: middle;
}

span.var {
    padding-left: 2px;
    padding-right: 2px;
}

span.const {
    padding-left: 2px;
    padding-right: 2px;
}

span.selected.var {
    color: white;
}

.live-range {
    display: inline-block;
    width: 2px;
    min-height: 1px;
    margin: 0;
    margin-right: 1px;
    padding: 0;
}

.trace-line-number {
    display: inline-block;
    width: 30px;
    height: 20px;
    text-align: right;
    margin-right: 5px;
}

.asm-mnemoic {
    color: #088A29;
    white-space: nowrap;
}

.trace-asm-line {
    margin-left: 35px;
}

.empty-rect {
    fill: none;
}

#forest {
    cursor: pointer;
    cursor: hand;
    background: #f8f8f8;
    border: 1px solid #e8e8e8;
    height: 150px;
    margin-bottom: 10px;
}

.trace-enter {
    fill: red;
}

.node .stitched {
    fill: #17BF17;
}

.node line.guard {
    stroke-width: 2px;
    stroke: #1D5D9B;
}

.node line.jump {
    stroke: black;
    stroke-width: 2px;
}

.guard-not-stitched {
    stroke: blue;
    stroke-width: 2px;
}
.guard-not-stitched-text {
    stroke: blue;
    font-size: 8px;
}

.link {
  fill: none;
  stroke: #000;
  stroke-width: 1px;
}

.live-ranges {
    width: 16px;
    margin: 0;
    padding: 0;
    margin-left: 5px;
    position: absolute;
}

.resop-content {
    /*display: inline-block;*/
    position: relative;
    left: 25px;
}

.navigate-up {
    margin-left: 35px;
    margin-right: 35px;
    margin-bottom: 10px;
    margin-top: 10px;
    background: white;
    border: 1px solid silver;
    padding: 10px;
}

.trace-line {
    white-space: nowrap;
    position: relative;
}


#help {
    position: relative;
    width: 100%;
}

.help-button {
    position: absolute;
    right: 0;
    margin-top: 10px;
    margin-right: 10px;
    z-index: 10;
}

#help-content {
    padding: 20px;
    padding-top: 10px;
    padding-bottom: 10px;
    width: 100%;
    position: absolute;
    display: none;
    background: #fafafa;
    padding-top: 10px;
    padding-bottom: 10px;
    border: 3px solid #e8e8e8;
    z-index: 9;
}

.trace-elem-preview {
    display: inline;
    width: 20px;
    height: 20px;
}

dl.inline dt {
    display: inline-block;
}
dl.inline dd {
    display: inline-block;
}

ul.inline {
    padding-left: 20px;
    margin: 0;
}

ul.inline li {
    padding: 0;
}

.source-code {
    position: relative;
    left: 5px;
}

code.trace-source {
    padding-left: 0;
    margin-left: 35px;
    background: none;
}

code.trace-source > pre {
    display: inline;
    background: none;
    border: none;
    padding: 0;
    margin: 0;
}

.byte-code {
    position: relative;
    left: 5px;
}

code.trace-bytecode {
    background: none;
    padding: 0;
    margin: 0;
    margin-left: 35px;
    color: #4682B4;
}
code.trace-bytecode > pre {
    border: 0;
    display: inline;
    background: none;
    color: inherit;
    padding: 0;
    margin: 0;
}

.resops {
    overflow-y: scroll;
    overflow-x: scroll;
    background: #fafafa;
    padding-top: 10px;
    padding-bottom: 10px;
    border: 1px solid #e8e8e8;
}

.trace-control {
    padding-right: 10px;
}

ul.trace-type-switch {
    list-style: none;
    margin: 0;
    padding: 0;
    overflow: hidden;
    display: inline-block;
}

ul.trace-type-switch li {
    display: inline-block;
    cursor: hand;
}

.opt-pipeline-help {
    background: black;
    color: white;
    padding: 3px;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
}

ul.trace-type-switch li a {
    display: inline-block;
    color: black;
    padding-left: 5px;
    padding-right: 5px;
    -webkit-border-top-left-radius: 5px;
    -webkit-border-top-right-radius: 5px;
    -moz-border-radius-topleft: 5px;
    -moz-border-radius-topright: 5px;
    border-top-left-radius: 5px;
    border-top-right-radius: 5px;
    margin-bottom: -4px;
}

span.placeholder {
    display: inline-block;
    width 1.5em;
}

ul.trace-type-switch li a:hover {
    background: #fafafa;
    text-decoration: none;
    border: 1px solid #e8e8e8;
}

ul.trace-type-switch li a.active {
    background: #fafafa;
    border: 1px solid #e8e8e8;
}

.resops-control {
    height: 32px;
    line-height: 32px;
    padding-top: 2px;
    padding-bottom: 2px;
}

ul.trace-entries {
    list-style: none;
    padding-left: 0;
}

.trace-entry {
    padding: 5px;
    cursor: pointer;
    background: #fafafa;
    margin-bottom: 2px;
}

.trace-entry.active {
    background: #eee;
}

.trace-entry:hover {
    background: #eee;
}

.trace-info {
    font-size: 10px;
    color: gray;
}

.trace-type {
    font-size: 10px;
    color: gray;
}

.trace-name {
    color: #008B31;
}

.trace-descr {
    display: inline-block;
    width: 100%;
    line-height: 20px;
}

.breathing-row {
    margin-bottom: 5px;
}

.trace-popover {
    fill
}

.trace-popover rect {
    stroke: silver;
    stroke-width: 1;
    fill: white;
}

.trace-popover text {
    font-size: 11px;
}


#legend-indicator > rect {
    cursor: hand;
    fill: black;
    stroke: #e8e8e8;
}

#legend-indicator > text {
    cursor: hand;
    fill: white;
    font: serif;
    font-size: 11px;
    stroke: #e8e8e8;
}

#loading_img > img {
    margin-bottom: 5px;
}
#loading_img {
  display: inline-block;
  position: fixed;
  left: 49%;
  margin: 50px auto 0 auto;
  text-align: center;
  padding: 10px;
  background: white;
  color: gray;
  border: 1px solid silver;
  -webkit-border-radius: 10px;
  -moz-border-radius: 10px;
  border-radius: 10px;
}

.measures {
    display: inline-block;
    font-size: 10px;
    color: gray;
    float: right;
    margin-top: 5px;
}

.vmprof-logo-navbar {
    margin: 0;
    margin-left: 10px;
    margin-right: 10px;
    width: 128;
    height: 22px;
}

.vmprof-navbar {
    display: inline-block;
    margin: 0 auto 0 auto;
    text-align: center;
    float: none;
}

.vmprof-nav {
    border-bottom: 4px solid #3a3a3b;
    margin-bottom: 10px;
}

.vmprof-nav a {
    color: #222120;
}

.content-top-profile-info {
  background: #eee;
  padding: 10px;
  margin-bottom: 10px;
}

.cpu-link-jit {
    float: right;
}
